pygeodesy.css.Css

Package pygeodesy :: Module css :: Class Css |
[frames] | no frames]

# Class Css

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      Css

Cassini-Soldner East-/Northing location.

Instance Methods
__init__(self, e, n, h=0, cs0=None, **name) New Css Cassini-Soldner position. |
toLatLon(self, LatLon=None, height=None, **LatLon_kwds) Convert this Css to an (ellipsoidal) geodetic point. |
toRepr(self, prec=6, fmt='[%s]', sep=', ', m=`'``m``'`, C=False) Return a string representation of this Css position. |
toStr(self, prec=6, sep=' ', m=`'``m``'`) Return a string representation of this Css position. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| azi Get the azimuth of easting direction (`degrees`).
| azimuth Get the azimuth of easting direction (`degrees`).
| cs0 Get the projection (CassiniSoldner).
| easting Get the easting (`meter`).
| height Get the height (`meter`).
| latlon Get the lat- and longitude (LatLon2Tuple).
| northing Get the northing (`meter`).
| reverse4 Get the lat, lon, azimuth and reciprocal (LatLonAziRk4Tuple).
| rk Get the reciprocal of azimuthal northing scale (`scalar`).
| reciprocal Get the reciprocal of azimuthal northing scale (`scalar`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, e, n, h=0, cs0=None, **name) (Constructor) |
New Css Cassini-Soldner position. Arguments: `e` - Easting (`meter`). `n` - Northing (`meter`). `h` - Optional height (`meter`). `cs0` - Optional, the Cassini-Soldner projection (CassiniSoldner). `name` - Optional `name=NN` (`str`). Returns: The Cassini-Soldner location (Css). Raises: `CSSError` - If `e` or `n` is invalid. `TypeError` - If `cs0` is not CassiniSoldner. `ValueError` - Invalid `h`. Overrides: object.__init__

### toLatLon (self, LatLon=None, height=None, **LatLon_kwds) |
Convert this Css to an (ellipsoidal) geodetic point. Arguments: `LatLon` - Optional, ellipsoidal class to return the geodetic point (`LatLon`) or `None`. `height` - Optional height for the point, overriding the default height (`meter`). `LatLon_kwds` - Optional, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: The geodetic point (`LatLon`) or if `LatLon is None`, a LatLon4Tuple`(lat, lon, height, datum)`. Raises: `TypeError` - If `LatLon` or `datum` is not ellipsoidal or invalid `height` or `LatLon_kwds`.

### toRepr (self, prec=6, fmt='[%s]', sep=', ', m=`'``m``'`, C=False) |
Return a string representation of this Css position. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Enclosing backets format (`str`). `sep` - Optional separator between name:values (`str`). `m` - Optional unit of the height, default meter (`str`). `C` - Optionally, include name of projection (`bool`). Returns: This position as `"[E:meter, N:meter, H:m, name:'', C:Conic.Datum]"` (`str`). Overrides: named._Named.toRepr

### toStr (self, prec=6, sep=' ', m=`'``m``'`) |
Return a string representation of this Css position. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `sep` - Optional separator to join (`str`) or `None` to return an unjoined `tuple` of `str`s. `m` - Height units, default `meter` (`str`). Returns: This position as `"easting nothing"` `str` in `meter` plus `" height"` and `'m'` if height is non-zero (`str`). Overrides: named._Named.toStr

Property Details

### azi Get the azimuth of easting direction (`degrees`). Get method: azi(self) - Get the azimuth of easting direction (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azimuth Get the azimuth of easting direction (`degrees`). Get method: azi(self) - Get the azimuth of easting direction (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### cs0 Get the projection (CassiniSoldner). Get method: cs0(self) - Get the projection (CassiniSoldner). Set method: cs0(self, cs0) - Set the Cassini-Soldner projection (CassiniSoldner). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### easting Get the easting (`meter`). Get method: easting(self) - Get the easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### height Get the height (`meter`). Get method: height(self) - Get the height (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get the lat- and longitude (LatLon2Tuple). Get method: latlon(self) - Get the lat- and longitude (LatLon2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### northing Get the northing (`meter`). Get method: northing(self) - Get the northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### reverse4 Get the lat, lon, azimuth and reciprocal (LatLonAziRk4Tuple). Get method: reverse4(self) - Get the lat, lon, azimuth and reciprocal (LatLonAziRk4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### rk Get the reciprocal of azimuthal northing scale (`scalar`). Get method: rk(self) - Get the reciprocal of azimuthal northing scale (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### reciprocal Get the reciprocal of azimuthal northing scale (`scalar`). Get method: rk(self) - Get the reciprocal of azimuthal northing scale (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.